﻿using System.ComponentModel;
using System.Windows.Markup;

namespace PassingDataThroughRadWindow
{
	[ContentProperty("Children")]
	public class DataItem : INotifyPropertyChanged
	{
		private string text;
		private string description;

		public DataItem()
		{
			this.Children = new DataItemCollection();
		}

		public string Text
		{
			get
			{
				return this.text;
			}
			set
			{
				if (this.text != value)
				{
					this.text = value;
					this.OnPropertyChanged("Text");
				}
			}
		}

		public string Description
		{
			get
			{
				return this.description;
			}
			set
			{
				if (this.description != value)
				{
					this.description = value;
					this.OnPropertyChanged("Description");
				}
			}
		}

		public DataItemCollection Children
		{
			get;
			private set;
		}

		public void CopyTo(DataItem target)
		{
			target.Text = this.Text;
			target.Description = this.Description;

			target.Children.Clear();
			foreach (DataItem child in this.Children)
			{
				target.Children.Add(child.Clone());
			}
		}

		public DataItem Clone()
		{
			DataItem clone = new DataItem();
			this.CopyTo(clone);
			return clone;
		}

		public event PropertyChangedEventHandler PropertyChanged;

		private void OnPropertyChanged(string propertyName)
		{
			if (this.PropertyChanged != null)
			{
				this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}
	}
}